@@ -23,10 +23,11 @@ class LedgerExecutor:
 
         if result.returncode != 0:
             output = result.stderr
+            raise Exception('Ledger error', output)
         else:
             output = result.stdout
         
-        output = self.split_lines(output)
+        #output = self.split_lines(output)
 
         return output
 
